pypel
=====

``pypel`` is a simple tool to manage receipts. It uses XMP to store metatada
inside receipts so you can share them in a very easy way.

.. IMPORTANT::
   pypel >=0.3 use GExiv2, pyexiv2 is not used anymore.

For more info see the documentation in the ``docs`` directory or browse it
online on `pypel.rtfd.org <http://pypel.rtfd.org/>`_.

* Code: `https://github.com/eriol/pypel <https://github.com/eriol/pypel>`_
* Bug reports: `https://github.com/eriol/pypel/issues <https://github.com/eriol/pypel/issues>`_
* License: BSD 3-Clause
